#
# spec file for package python-oslo.policy
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.policy
Name:           python-oslo.policy
Version:        1.14.0
Release:        1.1
Summary:        OpenStack Oslo Policy library
License:        Apache-2.0
Group:          Documentation
Url:            https://launchpad.net/%sname
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-PyYAML >= 3.1.0
BuildRequires:  python-devel
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.serialization >= 1.10.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-requests-mock >= 1.0
Requires:       python-PyYAML >= 3.1.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-requests >= 2.10.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
The OpenStack Oslo Policy library.
RBAC policy enforcement library for OpenStack.

%package doc
Summary:        Documentation for the Oslo Policy library
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for the Oslo Policy library.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst
%{_bindir}/oslopolicy-checker
%{_bindir}/oslopolicy-list-redundant
%{_bindir}/oslopolicy-policy-generator
%{_bindir}/oslopolicy-sample-generator
%{python2_sitelib}/oslo_policy
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Wed Aug 31 2016 tbechtold@suse.com
- update to version 1.14.0
  * Revert "Adds debug logging for policy file validation"
  * Delete H803 in flake8 ignore
  * Allow policy file to not exist
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.13.0
  * Fix mispelled method name in setup.cfg
  * Add note about not all APIs support policy enforcement by user_id
  * Imported Translations from Zanata
  * Fixed unit tests running on Windows
  * Add Python 3.5 classifier and venv
  * Adds debug logging for policy file validation
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.11.0:
  * Updated from global requirements
  * Imported Translations from Zanata
  * Improve policy sample generation testing
  * Add helper scripts for generating policy info
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.9.0:
  * Add sample file generation script and helper methods
  * Add equality operator to policy.RuleDefault
  * Imported Translations from Zanata
  * Updated from global requirements
  * Fix typo: 'olso' to 'oslo'
  * Updated from global requirements
  * Updated from global requirements
  * Add reno for release notes management
  * Add policy registration and authorize method
  * Updated from global requirements
  * doc: Fix wrong import statement in usage
* Sat Jun  4 2016 tbechtold@suse.com
- update to 1.8.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * Updated from global requirements
  * Imported Translations from Zanata
  * Deprecate load_json() in favor of load()
  * Support policy file in YAML
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Revert "Pass environment variables of proxy to tox"
  * Run docs testenv by default with tox
  * Add oslopolicy-checker command-line tool
  * Updated from global requirements
  * Don't crash on RoleCheck when roles not present
  * assertIsNone(val) instead of assertEqual(None,val)
  * Updated from global requirements
  * Add string format rendering to RoleCheck.__call__()
  * Pass environment variables of proxy to tox
  * Fixes combined "and" and "or" rule handling
  * Make sure item of policy_dirs is directory
  * Updated from global requirements
  * Use dict comprehension
  * Don't generate doc from test
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Use requests-mock instead of httpretty in tests
  * Clarify usage docs
  * Correct invalid doc references
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Use JSON generator
  * Add test for enforce with rule doesn't exist
  * Add test for raising default exception
  * Add test for invalid JSON
  * Add cover test requirement
  * Fix a typo in policy.py
  * Updated from global requirements
  * Custom fixture to avoid external call in HttpCheck
  * Fix coverage configuration and execution
  * add auto-generated docs for config options
  * Add shields.io version/downloads links/badges into README.rst
  * Updated from global requirements
  * Use requests in http check instead of urllib
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * remove deprecation text for policy_dirs option
- Switch to .spec from rpm-packaging upstream project
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.11.0:
  * Updated from global requirements
  * Pass reference then actual to assertEqual
  * Overwrite option should not cause policy file reloading
  * Updated from global requirements
  * Setup translations
  * Have the enforcer have its own file cache
  * Updated from global requirements
  * Updated from global requirements
- adjust Requires according requirements.txt
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.8.0:
  * Updated from global requirements
  * Fix typo of 'available' in token_fixture.py
  * Fixes up the API docs and module index
- adjust Requires according requirements.txt
* Fri Jul 17 2015 tbechtold@suse.com
- update to 0.7.0:
  * Remove oslo-incubator specific code
  * Move fileutils functions to oslo.policy
  * Add six and oslo.utils to requirements
  * Add tox target to find missing requirements
  * Updated from global requirements
  * Updated from global requirements
- Update Requires according to requirements.txt
* Wed Jun 10 2015 tbechtold@suse.com
- update to 0.6.0:
  * Fix Enforcer docstring
- Run testsuite in parallel
* Mon Jun  8 2015 tbechtold@suse.com
- update to 0.5.0:
  * Expose base check classes as part of public API
  * Uncap library requirements for liberty
  * Fix invalid indentation in _load_policy_file method
  * Cleanup README.rst and setup.cfg
  * Avoid reloading policy files in policy.d for every call
  * Lists for Generic Checks
  * Updated from global requirements
- Update Requires according to requirements.txt
* Mon Jun  1 2015 dmueller@suse.com
- remove wildcards from the filelist
* Mon Mar 16 2015 tbechtold@suse.com
- Enable tests during build
- Adjust Requires and BuildRequires
* Mon Mar 16 2015 tbechtold@suse.com
- Initial packaging
